@@ -1,6 +1,3 @@
-#
-#
-#
 import sys
 import os
 import tarfile
@@ -8,13 +5,14 @@ import Benno
 
 def fromConfig(configfile,args):
     for container in Benno.Config(configfile).containers:
+        if args.verbose > 0: print >> sys.stderr, "Backup container: %s" % container.id
         repo=container.getRepo()
-        if args.full:
-            statusfile=False
-        elif args.statusfile:
-            statusfile=args.statusfile
-        else:    
+        if args.increment:
             statusfile=repo.path+os.sep+'backup.status'
+        else:
+            statusfile=False
+        if args.statusfile:
+            statusfile=args.statusfile
         if args.purge_status:
             try:
                 if args.verbose > 0: print >> sys.stderr, "Remove status file: %s" % statusfile
@@ -30,8 +28,20 @@ def fromConfig(configfile,args):
                 oldhash=f.readline().rstrip()
                 f.close()
             except IOError: pass
-        if args.tarfile:
-            newesthash=writeTar(repo,oldhash,args)
+        # tar output
+        if args.tarfile and not args.list:
+            if args.tarfile=='-':
+                # open at first container
+                try:
+                    tar
+                except NameError:
+                    tar=tarfile.open(fileobj=sys.stdout,mode='w|')
+            else:
+                tar=tarfile.open(args.tarfile,'a')
+            newesthash=writeTar(repo,oldhash,args,tar)
+            if not args.tarfile=='-':
+                tar.close()
+        # print filenames
         else:
             newesthash=printFiles(repo,oldhash,args)
         if statusfile:
@@ -73,7 +83,7 @@ def fromRepo(args):
 
 
 ############################################################################
-def writeTar(repo,oldhash,args):
+def writeTar(repo,oldhash,args,tar):
     journal=Benno.Journal()
     for box in Benno.Box.GetBoxes(repo.boxstate):
         for journalfile in box.journalfiles:
@@ -86,20 +96,17 @@ def writeTar(repo,oldhash,args):
     except IndexError: pass
 
     reposubdir=repo.path
-    if args.tarfile=='-':
-        tar=tarfile.open(fileobj=sys.stdout,mode='w|')
-    else:
-        tar=tarfile.open(args.tarfile,'w')
     for jfile in journalfiles:
         currenthash=''
         mailhashes=jfile.getHashes()
         jFileName=jfile.file
         path,repoJfileName=jFileName.split(reposubdir)
         backupJfileName=reposubdir+repoJfileName
+        if args.verbose > 2: print >> sys.stderr, "Add file %s" % backupJfileName
         tar.add(jfile.file,backupJfileName)
         for currenthash in mailhashes:
             if currenthash==oldhash:
-                tar.close()
+                #tar.close()
                 return newesthash
             file2backup=jfile.box.fileFromHash(currenthash)
             path,repoFileName=file2backup.split(reposubdir)
@@ -110,7 +117,6 @@ def writeTar(repo,oldhash,args):
                 print >> sys.stderr, "ERROR: Cannot add \"%s\" to tar archive: \"%s\"" % (file2backup,e[1])
             except KeyboardInterrupt:
                 sys.exit("Exit.")
-    tar.close()
     return newesthash
 
 # print full path of repo file
